summaryrefslogtreecommitdiff
path: root/src/mainboard/iwill/dk8x/irq_tables.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/mainboard/iwill/dk8x/irq_tables.c')
-rw-r--r--src/mainboard/iwill/dk8x/irq_tables.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/mainboard/iwill/dk8x/irq_tables.c b/src/mainboard/iwill/dk8x/irq_tables.c
index 6322c3df21..1f35cbaef2 100644
--- a/src/mainboard/iwill/dk8x/irq_tables.c
+++ b/src/mainboard/iwill/dk8x/irq_tables.c
@@ -18,7 +18,7 @@
const struct irq_routing_table intel_irq_routing_table = {
PIRQ_SIGNATURE, /* u32 signature */
PIRQ_VERSION, /* u16 version */
- 32+16*IRQ_SLOT_COUNT, /* there can be total IRQ_SLOT_COUNT
+ 32+16*CONFIG_IRQ_SLOT_COUNT, /* there can be total CONFIG_IRQ_SLOT_COUNT
* devices on the bus */
IRQ_ROUTER_BUS, /* Where the interrupt router lies (bus) */
IRQ_ROUTER_DEVFN, /* Where the interrupt router lies (dev) */